# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: build/bazel/remote/logstream/v1/remote_logstream.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6build/bazel/remote/logstream/v1/remote_logstream.proto\x12\x1f\x62uild.bazel.remote.logstream.v1\"(\n\x16\x43reateLogStreamRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\"6\n\tLogStream\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x13write_resource_name\x18\x02 \x01(\t2\x8c\x01\n\x10LogStreamService\x12x\n\x0f\x43reateLogStream\x12\x37.build.bazel.remote.logstream.v1.CreateLogStreamRequest\x1a*.build.bazel.remote.logstream.v1.LogStream\"\x00\x42q\n\x1f\x62uild.bazel.remote.logstream.v1B\x14RemoteLogStreamProtoP\x01Z\x0fremotelogstream\xa2\x02\x02RL\xaa\x02\x1f\x42uild.Bazel.Remote.LogStream.v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buildgrid.common.protos.build.bazel.remote.logstream.v1.remote_logstream_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037build.bazel.remote.logstream.v1B\024RemoteLogStreamProtoP\001Z\017remotelogstream\242\002\002RL\252\002\037Build.Bazel.Remote.LogStream.v1'
  _globals['_CREATELOGSTREAMREQUEST']._serialized_start=91
  _globals['_CREATELOGSTREAMREQUEST']._serialized_end=131
  _globals['_LOGSTREAM']._serialized_start=133
  _globals['_LOGSTREAM']._serialized_end=187
  _globals['_LOGSTREAMSERVICE']._serialized_start=190
  _globals['_LOGSTREAMSERVICE']._serialized_end=330
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (C) 2021 Bloomberg LP

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ExecutionStatistics(google.protobuf.message.Message):
    """Message containing metrics about the execution of a command. To be attached
    to `build.bazel.remote.execution.v2.ExecutedActionMetadata.auxiliary_metadata`.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ProcessResourceUsage(google.protobuf.message.Message):
        """Values gathered from `getrusage(2)`."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        UTIME_FIELD_NUMBER: builtins.int
        STIME_FIELD_NUMBER: builtins.int
        MAXRSS_FIELD_NUMBER: builtins.int
        MINFLT_FIELD_NUMBER: builtins.int
        MAJFLT_FIELD_NUMBER: builtins.int
        INBLOCK_FIELD_NUMBER: builtins.int
        OUBLOCK_FIELD_NUMBER: builtins.int
        NVCSW_FIELD_NUMBER: builtins.int
        NIVCSW_FIELD_NUMBER: builtins.int
        @property
        def utime(self) -> google.protobuf.duration_pb2.Duration:
            """User CPU time used"""
        @property
        def stime(self) -> google.protobuf.duration_pb2.Duration:
            """System CPU time used"""
        maxrss: builtins.int
        """Maximum resident set size used [kb]"""
        minflt: builtins.int
        """Number of page faults serviced without I/O activity (reclaims)"""
        majflt: builtins.int
        """Number of page faults serviced that required I/O activity (faults)"""
        inblock: builtins.int
        """Number of times the filesystem performed inputs/outputs"""
        oublock: builtins.int
        nvcsw: builtins.int
        """Number of voluntary/involuntary context switches"""
        nivcsw: builtins.int
        def __init__(
            self,
            *,
            utime: google.protobuf.duration_pb2.Duration | None = ...,
            stime: google.protobuf.duration_pb2.Duration | None = ...,
            maxrss: builtins.int = ...,
            minflt: builtins.int = ...,
            majflt: builtins.int = ...,
            inblock: builtins.int = ...,
            oublock: builtins.int = ...,
            nvcsw: builtins.int = ...,
            nivcsw: builtins.int = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["stime", b"stime", "utime", b"utime"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["inblock", b"inblock", "majflt", b"majflt", "maxrss", b"maxrss", "minflt", b"minflt", "nivcsw", b"nivcsw", "nvcsw", b"nvcsw", "oublock", b"oublock", "stime", b"stime", "utime", b"utime"]) -> None: ...

    COMMAND_RUSAGE_FIELD_NUMBER: builtins.int
    @property
    def command_rusage(self) -> global___ExecutionStatistics.ProcessResourceUsage:
        """`getrusage()` measurements from the command's execution"""
    def __init__(
        self,
        *,
        command_rusage: global___ExecutionStatistics.ProcessResourceUsage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["command_rusage", b"command_rusage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["command_rusage", b"command_rusage"]) -> None: ...

global___ExecutionStatistics = ExecutionStatistics



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buildstream/v2/buildstream.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buildgrid.common.protos.build.bazel.remote.execution.v2 import remote_execution_pb2 as build_dot_bazel_dot_remote_dot_execution_dot_v2_dot_remote__execution__pb2
from buildgrid.common.protos.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n buildstream/v2/buildstream.proto\x12\x0e\x62uildstream.v2\x1a\x36\x62uild/bazel/remote/execution/v2/remote_execution.proto\x1a\x1cgoogle/api/annotations.proto\"9\n\x13GetReferenceRequest\x12\x15\n\rinstance_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"O\n\x14GetReferenceResponse\x12\x37\n\x06\x64igest\x18\x01 \x01(\x0b\x32\'.build.bazel.remote.execution.v2.Digest\"v\n\x16UpdateReferenceRequest\x12\x15\n\rinstance_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x37\n\x06\x64igest\x18\x03 \x01(\x0b\x32\'.build.bazel.remote.execution.v2.Digest\"\x19\n\x17UpdateReferenceResponse\"&\n\rStatusRequest\x12\x15\n\rinstance_name\x18\x01 \x01(\t\"\'\n\x0eStatusResponse\x12\x15\n\rallow_updates\x18\x01 \x01(\x08\x32\xca\x03\n\x10ReferenceStorage\x12\x90\x01\n\x0cGetReference\x12#.buildstream.v2.GetReferenceRequest\x1a$.buildstream.v2.GetReferenceResponse\"5\x82\xd3\xe4\x93\x02/\x12-/v2/{instance_name=**}/buildstream/refs/{key}\x12\xa1\x01\n\x0fUpdateReference\x12&.buildstream.v2.UpdateReferenceRequest\x1a\'.buildstream.v2.UpdateReferenceResponse\"=\x82\xd3\xe4\x93\x02\x37\x1a-/v2/{instance_name=**}/buildstream/refs/{key}:\x06\x64igest\x12\x7f\n\x06Status\x12\x1d.buildstream.v2.StatusRequest\x1a\x1e.buildstream.v2.StatusResponse\"6\x82\xd3\xe4\x93\x02\x30\x1a./v2/{instance_name=**}/buildstream/refs:statusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buildgrid.common.protos.buildstream.v2.buildstream_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REFERENCESTORAGE.methods_by_name['GetReference']._options = None
  _REFERENCESTORAGE.methods_by_name['GetReference']._serialized_options = b'\202\323\344\223\002/\022-/v2/{instance_name=**}/buildstream/refs/{key}'
  _REFERENCESTORAGE.methods_by_name['UpdateReference']._options = None
  _REFERENCESTORAGE.methods_by_name['UpdateReference']._serialized_options = b'\202\323\344\223\0027\032-/v2/{instance_name=**}/buildstream/refs/{key}:\006digest'
  _REFERENCESTORAGE.methods_by_name['Status']._options = None
  _REFERENCESTORAGE.methods_by_name['Status']._serialized_options = b'\202\323\344\223\0020\032./v2/{instance_name=**}/buildstream/refs:status'
  _globals['_GETREFERENCEREQUEST']._serialized_start=138
  _globals['_GETREFERENCEREQUEST']._serialized_end=195
  _globals['_GETREFERENCERESPONSE']._serialized_start=197
  _globals['_GETREFERENCERESPONSE']._serialized_end=276
  _globals['_UPDATEREFERENCEREQUEST']._serialized_start=278
  _globals['_UPDATEREFERENCEREQUEST']._serialized_end=396
  _globals['_UPDATEREFERENCERESPONSE']._serialized_start=398
  _globals['_UPDATEREFERENCERESPONSE']._serialized_end=423
  _globals['_STATUSREQUEST']._serialized_start=425
  _globals['_STATUSREQUEST']._serialized_end=463
  _globals['_STATUSRESPONSE']._serialized_start=465
  _globals['_STATUSRESPONSE']._serialized_end=504
  _globals['_REFERENCESTORAGE']._serialized_start=507
  _globals['_REFERENCESTORAGE']._serialized_end=965
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2018 Codethink Limited

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GetReferenceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_NAME_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    instance_name: builtins.str
    """The instance of the execution system to operate against. A server may
    support multiple instances of the execution system (with their own workers,
    storage, caches, etc.). The server MAY require use of this field to select
    between them in an implementation-defined fashion, otherwise it can be
    omitted.
    """
    key: builtins.str
    """The name of the reference."""
    def __init__(
        self,
        *,
        instance_name: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_name", b"instance_name", "key", b"key"]) -> None: ...

global___GetReferenceRequest = GetReferenceRequest

@typing_extensions.final
class GetReferenceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DIGEST_FIELD_NUMBER: builtins.int
    @property
    def digest(self) -> buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.Digest:
        """The digest of the CAS [Directory][build.bazel.remote.execution.v2.Directory]."""
    def __init__(
        self,
        *,
        digest: buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.Digest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["digest", b"digest"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["digest", b"digest"]) -> None: ...

global___GetReferenceResponse = GetReferenceResponse

@typing_extensions.final
class UpdateReferenceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_NAME_FIELD_NUMBER: builtins.int
    KEYS_FIELD_NUMBER: builtins.int
    DIGEST_FIELD_NUMBER: builtins.int
    instance_name: builtins.str
    """The instance of the execution system to operate against. A server may
    support multiple instances of the execution system (with their own workers,
    storage, caches, etc.). The server MAY require use of this field to select
    between them in an implementation-defined fashion, otherwise it can be
    omitted.
    """
    @property
    def keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The name of the reference."""
    @property
    def digest(self) -> buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.Digest:
        """The digest of the CAS [Directory][build.bazel.remote.execution.v2.Directory]
        to store in the cache.
        """
    def __init__(
        self,
        *,
        instance_name: builtins.str = ...,
        keys: collections.abc.Iterable[builtins.str] | None = ...,
        digest: buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.Digest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["digest", b"digest"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["digest", b"digest", "instance_name", b"instance_name", "keys", b"keys"]) -> None: ...

global___UpdateReferenceRequest = UpdateReferenceRequest

@typing_extensions.final
class UpdateReferenceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateReferenceResponse = UpdateReferenceResponse

@typing_extensions.final
class StatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_NAME_FIELD_NUMBER: builtins.int
    instance_name: builtins.str
    """The instance of the execution system to operate against. A server may
    support multiple instances of the execution system (with their own workers,
    storage, caches, etc.). The server MAY require use of this field to select
    between them in an implementation-defined fashion, otherwise it can be
    omitted.
    """
    def __init__(
        self,
        *,
        instance_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_name", b"instance_name"]) -> None: ...

global___StatusRequest = StatusRequest

@typing_extensions.final
class StatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_UPDATES_FIELD_NUMBER: builtins.int
    allow_updates: builtins.bool
    """Whether reference updates are allowed for the connected client."""
    def __init__(
        self,
        *,
        allow_updates: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_updates", b"allow_updates"]) -> None: ...

global___StatusResponse = StatusResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/devtools/build/v1/publish_build_event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buildgrid.common.protos.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from buildgrid.common.protos.google.api import client_pb2 as google_dot_api_dot_client__pb2
from buildgrid.common.protos.google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from buildgrid.common.protos.google.devtools.build.v1 import build_events_pb2 as google_dot_devtools_dot_build_dot_v1_dot_build__events__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2google/devtools/build/v1/publish_build_event.proto\x12\x18google.devtools.build.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a+google/devtools/build/v1/build_events.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xe3\x02\n\x1cPublishLifecycleEventRequest\x12Z\n\rservice_level\x18\x01 \x01(\x0e\x32\x43.google.devtools.build.v1.PublishLifecycleEventRequest.ServiceLevel\x12\x46\n\x0b\x62uild_event\x18\x02 \x01(\x0b\x32+.google.devtools.build.v1.OrderedBuildEventB\x04\xe2\x41\x01\x02\x12\x31\n\x0estream_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1d\n\x15notification_keywords\x18\x04 \x03(\t\x12\x18\n\nproject_id\x18\x06 \x01(\tB\x04\xe2\x41\x01\x02\"3\n\x0cServiceLevel\x12\x12\n\x0eNONINTERACTIVE\x10\x00\x12\x0f\n\x0bINTERACTIVE\x10\x01\"u\n#PublishBuildToolEventStreamResponse\x12\x35\n\tstream_id\x18\x01 \x01(\x0b\x32\".google.devtools.build.v1.StreamId\x12\x17\n\x0fsequence_number\x18\x02 \x01(\x03\"\x98\x01\n\x11OrderedBuildEvent\x12\x35\n\tstream_id\x18\x01 \x01(\x0b\x32\".google.devtools.build.v1.StreamId\x12\x17\n\x0fsequence_number\x18\x02 \x01(\x03\x12\x33\n\x05\x65vent\x18\x03 \x01(\x0b\x32$.google.devtools.build.v1.BuildEvent\"\xad\x01\n\"PublishBuildToolEventStreamRequest\x12N\n\x13ordered_build_event\x18\x04 \x01(\x0b\x32+.google.devtools.build.v1.OrderedBuildEventB\x04\xe2\x41\x01\x02\x12\x1d\n\x15notification_keywords\x18\x05 \x03(\t\x12\x18\n\nproject_id\x18\x06 \x01(\tB\x04\xe2\x41\x01\x02\x32\xde\x04\n\x11PublishBuildEvent\x12\xc9\x01\n\x15PublishLifecycleEvent\x12\x36.google.devtools.build.v1.PublishLifecycleEventRequest\x1a\x16.google.protobuf.Empty\"`\x82\xd3\xe4\x93\x02Z\"3/v1/projects/{project_id=*}/lifecycleEvents:publish:\x01*Z \"\x1b/v1/lifecycleEvents:publish:\x01*\x12\xa6\x02\n\x1bPublishBuildToolEventStream\x12<.google.devtools.build.v1.PublishBuildToolEventStreamRequest\x1a=.google.devtools.build.v1.PublishBuildToolEventStreamResponse\"\x85\x01\xda\x41\x34ordered_build_event,notification_keywords,project_id\x82\xd3\xe4\x93\x02H\"*/v1/projects/{project_id=*}/events:publish:\x01*Z\x17\"\x12/v1/events:publish:\x01*(\x01\x30\x01\x1aT\xca\x41 buildeventservice.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformB\x88\x01\n\x1c\x63om.google.devtools.build.v1B\x0c\x42\x61\x63kendProtoP\x01Z=google.golang.org/genproto/googleapis/devtools/build/v1;build\xf8\x01\x01\xca\x02\x15Google\\Cloud\\Build\\V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buildgrid.common.protos.google.devtools.build.v1.publish_build_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.google.devtools.build.v1B\014BackendProtoP\001Z=google.golang.org/genproto/googleapis/devtools/build/v1;build\370\001\001\312\002\025Google\\Cloud\\Build\\V1'
  _PUBLISHLIFECYCLEEVENTREQUEST.fields_by_name['build_event']._options = None
  _PUBLISHLIFECYCLEEVENTREQUEST.fields_by_name['build_event']._serialized_options = b'\342A\001\002'
  _PUBLISHLIFECYCLEEVENTREQUEST.fields_by_name['project_id']._options = None
  _PUBLISHLIFECYCLEEVENTREQUEST.fields_by_name['project_id']._serialized_options = b'\342A\001\002'
  _PUBLISHBUILDTOOLEVENTSTREAMREQUEST.fields_by_name['ordered_build_event']._options = None
  _PUBLISHBUILDTOOLEVENTSTREAMREQUEST.fields_by_name['ordered_build_event']._serialized_options = b'\342A\001\002'
  _PUBLISHBUILDTOOLEVENTSTREAMREQUEST.fields_by_name['project_id']._options = None
  _PUBLISHBUILDTOOLEVENTSTREAMREQUEST.fields_by_name['project_id']._serialized_options = b'\342A\001\002'
  _PUBLISHBUILDEVENT._options = None
  _PUBLISHBUILDEVENT._serialized_options = b'\312A buildeventservice.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform'
  _PUBLISHBUILDEVENT.methods_by_name['PublishLifecycleEvent']._options = None
  _PUBLISHBUILDEVENT.methods_by_name['PublishLifecycleEvent']._serialized_options = b'\202\323\344\223\002Z\"3/v1/projects/{project_id=*}/lifecycleEvents:publish:\001*Z \"\033/v1/lifecycleEvents:publish:\001*'
  _PUBLISHBUILDEVENT.methods_by_name['PublishBuildToolEventStream']._options = None
  _PUBLISHBUILDEVENT.methods_by_name['PublishBuildToolEventStream']._serialized_options = b'\332A4ordered_build_event,notification_keywords,project_id\202\323\344\223\002H\"*/v1/projects/{project_id=*}/events:publish:\001*Z\027\"\022/v1/events:publish:\001*'
  _globals['_PUBLISHLIFECYCLEEVENTREQUEST']._serialized_start=275
  _globals['_PUBLISHLIFECYCLEEVENTREQUEST']._serialized_end=630
  _globals['_PUBLISHLIFECYCLEEVENTREQUEST_SERVICELEVEL']._serialized_start=579
  _globals['_PUBLISHLIFECYCLEEVENTREQUEST_SERVICELEVEL']._serialized_end=630
  _globals['_PUBLISHBUILDTOOLEVENTSTREAMRESPONSE']._serialized_start=632
  _globals['_PUBLISHBUILDTOOLEVENTSTREAMRESPONSE']._serialized_end=749
  _globals['_ORDEREDBUILDEVENT']._serialized_start=752
  _globals['_ORDEREDBUILDEVENT']._serialized_end=904
  _globals['_PUBLISHBUILDTOOLEVENTSTREAMREQUEST']._serialized_start=907
  _globals['_PUBLISHBUILDTOOLEVENTSTREAMREQUEST']._serialized_end=1080
  _globals['_PUBLISHBUILDEVENT']._serialized_start=1083
  _globals['_PUBLISHBUILDEVENT']._serialized_end=1689
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from buildgrid.common.protos.google.devtools.build.v1 import publish_build_event_pb2 as google_dot_devtools_dot_build_dot_v1_dot_publish__build__event__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class PublishBuildEventStub(object):
    """A service for publishing BuildEvents. BuildEvents are generated by Build
    Systems to record actions taken during a Build. Events occur in streams,
    are identified by a StreamId, and ordered by sequence number in a stream.

    A Build may contain several streams of BuildEvents, depending on the systems
    that are involved in the Build. Some BuildEvents are used to declare the
    beginning and end of major portions of a Build; these are called
    LifecycleEvents, and are used (for example) to indicate the beginning or end
    of a Build, and the beginning or end of an Invocation attempt (there can be
    more than 1 Invocation in a Build if, for example, a failure occurs somewhere
    and it needs to be retried).

    Other, build-tool events represent actions taken by the Build tool, such as
    target objects produced via compilation, tests run, et cetera. There could be
    more than one build tool stream for an invocation attempt of a build.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.PublishLifecycleEvent = channel.unary_unary(
                '/google.devtools.build.v1.PublishBuildEvent/PublishLifecycleEvent',
                request_serializer=google_dot_devtools_dot_build_dot_v1_dot_publish__build__event__pb2.PublishLifecycleEventRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.PublishBuildToolEventStream = channel.stream_stream(
                '/google.devtools.build.v1.PublishBuildEvent/PublishBuildToolEventStream',
                request_serializer=google_dot_devtools_dot_build_dot_v1_dot_publish__build__event__pb2.PublishBuildToolEventStreamRequest.SerializeToString,
                response_deserializer=google_dot_devtools_dot_build_dot_v1_dot_publish__build__event__pb2.PublishBuildToolEventStreamResponse.FromString,
                )


class PublishBuildEventServicer(object):
    """A service for publishing BuildEvents. BuildEvents are generated by Build
    Systems to record actions taken during a Build. Events occur in streams,
    are identified by a StreamId, and ordered by sequence number in a stream.

    A Build may contain several streams of BuildEvents, depending on the systems
    that are involved in the Build. Some BuildEvents are used to declare the
    beginning and end of major portions of a Build; these are called
    LifecycleEvents, and are used (for example) to indicate the beginning or end
    of a Build, and the beginning or end of an Invocation attempt (there can be
    more than 1 Invocation in a Build if, for example, a failure occurs somewhere
    and it needs to be retried).

    Other, build-tool events represent actions taken by the Build tool, such as
    target objects produced via compilation, tests run, et cetera. There could be
    more than one build tool stream for an invocation attempt of a build.
    """

    def PublishLifecycleEvent(self, request, context):
        """Publish a build event stating the new state of a build (typically from the
        build queue). The BuildEnqueued event must be publishd before all other
        events for the same build ID.

        The backend will persist the event and deliver it to registered frontend
        jobs immediately without batching.

        The commit status of the request is reported by the RPC's util_status()
        function. The error code is the canoncial error code defined in
        //util/task/codes.proto.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PublishBuildToolEventStream(self, request_iterator, context):
        """Publish build tool events belonging to the same stream to a backend job
        using bidirectional streaming.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PublishBuildEventServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'PublishLifecycleEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.PublishLifecycleEvent,
                    request_deserializer=google_dot_devtools_dot_build_dot_v1_dot_publish__build__event__pb2.PublishLifecycleEventRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'PublishBuildToolEventStream': grpc.stream_stream_rpc_method_handler(
                    servicer.PublishBuildToolEventStream,
                    request_deserializer=google_dot_devtools_dot_build_dot_v1_dot_publish__build__event__pb2.PublishBuildToolEventStreamRequest.FromString,
                    response_serializer=google_dot_devtools_dot_build_dot_v1_dot_publish__build__event__pb2.PublishBuildToolEventStreamResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'google.devtools.build.v1.PublishBuildEvent', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PublishBuildEvent(object):
    """A service for publishing BuildEvents. BuildEvents are generated by Build
    Systems to record actions taken during a Build. Events occur in streams,
    are identified by a StreamId, and ordered by sequence number in a stream.

    A Build may contain several streams of BuildEvents, depending on the systems
    that are involved in the Build. Some BuildEvents are used to declare the
    beginning and end of major portions of a Build; these are called
    LifecycleEvents, and are used (for example) to indicate the beginning or end
    of a Build, and the beginning or end of an Invocation attempt (there can be
    more than 1 Invocation in a Build if, for example, a failure occurs somewhere
    and it needs to be retried).

    Other, build-tool events represent actions taken by the Build tool, such as
    target objects produced via compilation, tests run, et cetera. There could be
    more than one build tool stream for an invocation attempt of a build.
    """

    @staticmethod
    def PublishLifecycleEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/google.devtools.build.v1.PublishBuildEvent/PublishLifecycleEvent',
            google_dot_devtools_dot_build_dot_v1_dot_publish__build__event__pb2.PublishLifecycleEventRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PublishBuildToolEventStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/google.devtools.build.v1.PublishBuildEvent/PublishBuildToolEventStream',
            google_dot_devtools_dot_build_dot_v1_dot_publish__build__event__pb2.PublishBuildToolEventStreamRequest.SerializeToString,
            google_dot_devtools_dot_build_dot_v1_dot_publish__build__event__pb2.PublishBuildToolEventStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buildgrid/v2/messaging.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buildgrid.common.protos.build.bazel.remote.execution.v2 import remote_execution_pb2 as build_dot_bazel_dot_remote_dot_execution_dot_v2_dot_remote__execution__pb2
from buildgrid.common.protos.google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x62uildgrid/v2/messaging.proto\x12\x0c\x62uildgrid.v2\x1a\x36\x62uild/bazel/remote/execution/v2/remote_execution.proto\x1a#google/longrunning/operations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"N\n\x03Job\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x37\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32\'.build.bazel.remote.execution.v2.Action\"\x87\x02\n\x0f\x43reateOperation\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x16\n\x0eoperation_name\x18\x02 \x01(\t\x12>\n\raction_digest\x18\x03 \x01(\x0b\x32\'.build.bazel.remote.execution.v2.Digest\x12\x11\n\tcacheable\x18\x04 \x01(\x08\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12J\n\x10request_metadata\x18\x06 \x01(\x0b\x32\x30.build.bazel.remote.execution.v2.RequestMetadata\"\x9c\x01\n\x10UpdateOperations\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x36\n\x0foperation_state\x18\x02 \x01(\x0b\x32\x1d.google.longrunning.Operation\x12\x11\n\tcacheable\x18\x03 \x01(\x08\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"l\n\x0cRetryableJob\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x37\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32\'.build.bazel.remote.execution.v2.Action\x12\x13\n\x0brouting_key\x18\x03 \x01(\t\"\x88\x01\n\tBotStatus\x12\x10\n\x08\x62ot_name\x18\x01 \x01(\t\x12/\n\x0b\x61ssignments\x18\x02 \x03(\x0b\x32\x1a.buildgrid.v2.RetryableJob\x12\x38\n\x14\x63onnection_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestampb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buildgrid.common.protos.buildgrid.v2.messaging_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_JOB']._serialized_start=172
  _globals['_JOB']._serialized_end=250
  _globals['_CREATEOPERATION']._serialized_start=253
  _globals['_CREATEOPERATION']._serialized_end=516
  _globals['_UPDATEOPERATIONS']._serialized_start=519
  _globals['_UPDATEOPERATIONS']._serialized_end=675
  _globals['_RETRYABLEJOB']._serialized_start=677
  _globals['_RETRYABLEJOB']._serialized_end=785
  _globals['_BOTSTATUS']._serialized_start=788
  _globals['_BOTSTATUS']._serialized_end=924
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2018 Google LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import buildgrid.common.protos.google.rpc.status_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CommandTask(google.protobuf.message.Message):
    """Describes a shell-style task to execute, suitable for providing as the Bots
    interface's `Lease.payload` field.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class Inputs(google.protobuf.message.Message):
        """Describes the inputs to a shell-style task."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing_extensions.final
        class EnvironmentVariable(google.protobuf.message.Message):
            """An environment variable required by this task."""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            NAME_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            name: builtins.str
            """The envvar name."""
            value: builtins.str
            """The envvar value."""
            def __init__(
                self,
                *,
                name: builtins.str = ...,
                value: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

        ARGUMENTS_FIELD_NUMBER: builtins.int
        FILES_FIELD_NUMBER: builtins.int
        ENVIRONMENT_VARIABLES_FIELD_NUMBER: builtins.int
        @property
        def arguments(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """The command itself to run (e.g., argv).

            This field should be passed directly to the underlying operating system,
            and so it must be sensible to that operating system. For example, on
            Windows, the first argument might be "C:\\Windows\\System32\\ping.exe" -
            that is, using drive letters and backslashes. A command for a *nix
            system, on the other hand, would use forward slashes.

            All other fields in the RWAPI must consistently use forward slashes,
            since those fields may be interpretted by both the service and the bot.
            """
        @property
        def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Digest]:
            """The input filesystem to be set up prior to the task beginning. The
            contents should be a repeated set of FileMetadata messages though other
            formats are allowed if better for the implementation (eg, a LUCI-style
            .isolated file).

            This field is repeated since implementations might want to cache the
            metadata, in which case it may be useful to break up portions of the
            filesystem that change frequently (eg, specific input files) from those
            that don't (eg, standard header files).
            """
        @property
        def environment_variables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CommandTask.Inputs.EnvironmentVariable]:
            """All environment variables required by the task."""
        def __init__(
            self,
            *,
            arguments: collections.abc.Iterable[builtins.str] | None = ...,
            files: collections.abc.Iterable[global___Digest] | None = ...,
            environment_variables: collections.abc.Iterable[global___CommandTask.Inputs.EnvironmentVariable] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["arguments", b"arguments", "environment_variables", b"environment_variables", "files", b"files"]) -> None: ...

    @typing_extensions.final
    class Outputs(google.protobuf.message.Message):
        """Describes the expected outputs of the command."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FILES_FIELD_NUMBER: builtins.int
        DIRECTORIES_FIELD_NUMBER: builtins.int
        STDOUT_DESTINATION_FIELD_NUMBER: builtins.int
        STDERR_DESTINATION_FIELD_NUMBER: builtins.int
        @property
        def files(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """A list of expected files, relative to the execution root. All paths
            MUST be delimited by forward slashes.
            """
        @property
        def directories(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """A list of expected directories, relative to the execution root. All paths
            MUST be delimited by forward slashes.
            """
        stdout_destination: builtins.str
        """The destination to which any stdout should be sent. The method by which
        the bot should send the stream contents to that destination is not
        defined in this API. As examples, the destination could be a file
        referenced in the `files` field in this message, or it could be a URI
        that must be written via the ByteStream API.
        """
        stderr_destination: builtins.str
        """The destination to which any stderr should be sent. The method by which
        the bot should send the stream contents to that destination is not
        defined in this API. As examples, the destination could be a file
        referenced in the `files` field in this message, or it could be a URI
        that must be written via the ByteStream API.
        """
        def __init__(
            self,
            *,
            files: collections.abc.Iterable[builtins.str] | None = ...,
            directories: collections.abc.Iterable[builtins.str] | None = ...,
            stdout_destination: builtins.str = ...,
            stderr_destination: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["directories", b"directories", "files", b"files", "stderr_destination", b"stderr_destination", "stdout_destination", b"stdout_destination"]) -> None: ...

    @typing_extensions.final
    class Timeouts(google.protobuf.message.Message):
        """Describes the timeouts associated with this task."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EXECUTION_FIELD_NUMBER: builtins.int
        IDLE_FIELD_NUMBER: builtins.int
        SHUTDOWN_FIELD_NUMBER: builtins.int
        @property
        def execution(self) -> google.protobuf.duration_pb2.Duration:
            """This specifies the maximum time that the task can run, excluding the
            time required to download inputs or upload outputs. That is, the worker
            will terminate the task if it runs longer than this.
            """
        @property
        def idle(self) -> google.protobuf.duration_pb2.Duration:
            """This specifies the maximum amount of time the task can be idle - that is,
            go without generating some output in either stdout or stderr. If the
            process is silent for more than the specified time, the worker will
            terminate the task.
            """
        @property
        def shutdown(self) -> google.protobuf.duration_pb2.Duration:
            """If the execution or IO timeouts are exceeded, the worker will try to
            gracefully terminate the task and return any existing logs. However,
            tasks may be hard-frozen in which case this process will fail. This
            timeout specifies how long to wait for a terminated task to shut down
            gracefully (e.g. via SIGTERM) before we bring down the hammer (e.g.
            SIGKILL on *nix, CTRL_BREAK_EVENT on Windows).
            """
        def __init__(
            self,
            *,
            execution: google.protobuf.duration_pb2.Duration | None = ...,
            idle: google.protobuf.duration_pb2.Duration | None = ...,
            shutdown: google.protobuf.duration_pb2.Duration | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["execution", b"execution", "idle", b"idle", "shutdown", b"shutdown"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["execution", b"execution", "idle", b"idle", "shutdown", b"shutdown"]) -> None: ...

    INPUTS_FIELD_NUMBER: builtins.int
    EXPECTED_OUTPUTS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    @property
    def inputs(self) -> global___CommandTask.Inputs:
        """The inputs to the task."""
    @property
    def expected_outputs(self) -> global___CommandTask.Outputs:
        """The expected outputs from the task."""
    @property
    def timeouts(self) -> global___CommandTask.Timeouts:
        """The timeouts of this task."""
    def __init__(
        self,
        *,
        inputs: global___CommandTask.Inputs | None = ...,
        expected_outputs: global___CommandTask.Outputs | None = ...,
        timeouts: global___CommandTask.Timeouts | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expected_outputs", b"expected_outputs", "inputs", b"inputs", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expected_outputs", b"expected_outputs", "inputs", b"inputs", "timeouts", b"timeouts"]) -> None: ...

global___CommandTask = CommandTask

@typing_extensions.final
class CommandOutputs(google.protobuf.message.Message):
    """DEPRECATED - use CommandResult instead.
    Describes the actual outputs from the task.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXIT_CODE_FIELD_NUMBER: builtins.int
    OUTPUTS_FIELD_NUMBER: builtins.int
    exit_code: builtins.int
    """exit_code is only fully reliable if the status' code is OK. If the task
    exceeded its deadline or was cancelled, the process may still produce an
    exit code as it is cancelled, and this will be populated, but a successful
    (zero) is unlikely to be correct unless the status code is OK.
    """
    @property
    def outputs(self) -> global___Digest:
        """The output files. The blob referenced by the digest should contain
        one of the following (implementation-dependent):
           * A marshalled DirectoryMetadata of the returned filesystem
           * A LUCI-style .isolated file
        """
    def __init__(
        self,
        *,
        exit_code: builtins.int = ...,
        outputs: global___Digest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["outputs", b"outputs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exit_code", b"exit_code", "outputs", b"outputs"]) -> None: ...

global___CommandOutputs = CommandOutputs

@typing_extensions.final
class CommandOverhead(google.protobuf.message.Message):
    """DEPRECATED - use CommandResult instead.
    Can be used as part of CompleteRequest.metadata, or are part of a more
    sophisticated message.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DURATION_FIELD_NUMBER: builtins.int
    OVERHEAD_FIELD_NUMBER: builtins.int
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """The elapsed time between calling Accept and Complete. The server will also
        have its own idea of what this should be, but this excludes the overhead of
        the RPCs and the bot response time.
        """
    @property
    def overhead(self) -> google.protobuf.duration_pb2.Duration:
        """The amount of time *not* spent executing the command (ie
        uploading/downloading files).
        """
    def __init__(
        self,
        *,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
        overhead: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration", "overhead", b"overhead"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration", "overhead", b"overhead"]) -> None: ...

global___CommandOverhead = CommandOverhead

@typing_extensions.final
class CommandResult(google.protobuf.message.Message):
    """All information about the execution of a command, suitable for providing as
    the Bots interface's `Lease.result` field.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    EXIT_CODE_FIELD_NUMBER: builtins.int
    OUTPUTS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    OVERHEAD_FIELD_NUMBER: builtins.int
    STATISTICS_FIELD_NUMBER: builtins.int
    @property
    def status(self) -> buildgrid.common.protos.google.rpc.status_pb2.Status:
        """An overall status for the command. For example, if the command timed out,
        this might have a code of DEADLINE_EXCEEDED; if it was killed by the OS for
        memory exhaustion, it might have a code of RESOURCE_EXHAUSTED.
        """
    exit_code: builtins.int
    """The exit code of the process. An exit code of "0" should only be trusted if
    `status` has a code of OK (otherwise it may simply be unset).
    """
    @property
    def outputs(self) -> global___Digest:
        """The output files. The blob referenced by the digest should contain
        one of the following (implementation-dependent):
           * A marshalled DirectoryMetadata of the returned filesystem
           * A LUCI-style .isolated file
        """
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """The elapsed time between calling Accept and Complete. The server will also
        have its own idea of what this should be, but this excludes the overhead of
        the RPCs and the bot response time.
        """
    @property
    def overhead(self) -> google.protobuf.duration_pb2.Duration:
        """The amount of time *not* spent executing the command (ie
        uploading/downloading files).
        """
    @property
    def statistics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """Implementation-dependent statistics about the task. Both servers and bots
        may define messages which can be encoded here; bots are free to provide
        statistics in multiple formats, and servers are free to choose one or more
        of the values to process and ignore others. In particular, it is *not*
        considered an error for the bot to provide the server with a field that it
        doesn't know about.
        """
    def __init__(
        self,
        *,
        status: buildgrid.common.protos.google.rpc.status_pb2.Status | None = ...,
        exit_code: builtins.int = ...,
        outputs: global___Digest | None = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
        overhead: google.protobuf.duration_pb2.Duration | None = ...,
        statistics: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration", "outputs", b"outputs", "overhead", b"overhead", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration", "exit_code", b"exit_code", "outputs", b"outputs", "overhead", b"overhead", "statistics", b"statistics", "status", b"status"]) -> None: ...

global___CommandResult = CommandResult

@typing_extensions.final
class FileMetadata(google.protobuf.message.Message):
    """The metadata for a file. Similar to the equivalent message in the Remote
    Execution API.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    DIGEST_FIELD_NUMBER: builtins.int
    CONTENTS_FIELD_NUMBER: builtins.int
    IS_EXECUTABLE_FIELD_NUMBER: builtins.int
    path: builtins.str
    """The path of this file. If this message is part of the
    CommandOutputs.outputs fields, the path is relative to the execution root
    and must correspond to an entry in CommandTask.outputs.files. If this
    message is part of a Directory message, then the path is relative to the
    root of that directory. All paths MUST be delimited by forward slashes.
    """
    @property
    def digest(self) -> global___Digest:
        """A pointer to the contents of the file. The method by which a client
        retrieves the contents from a CAS system is not defined here.
        """
    contents: builtins.bytes
    """If the file is small enough, its contents may also or alternatively be
    listed here.
    """
    is_executable: builtins.bool
    """Properties of the file"""
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        digest: global___Digest | None = ...,
        contents: builtins.bytes = ...,
        is_executable: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["digest", b"digest"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["contents", b"contents", "digest", b"digest", "is_executable", b"is_executable", "path", b"path"]) -> None: ...

global___FileMetadata = FileMetadata

@typing_extensions.final
class DirectoryMetadata(google.protobuf.message.Message):
    """The metadata for a directory. Similar to the equivalent message in the Remote
    Execution API.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    DIGEST_FIELD_NUMBER: builtins.int
    path: builtins.str
    """The path of the directory, as in [FileMetadata.path][google.devtools.remoteworkers.v1test2.FileMetadata.path]."""
    @property
    def digest(self) -> global___Digest:
        """A pointer to the contents of the directory, in the form of a marshalled
        Directory message.
        """
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        digest: global___Digest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["digest", b"digest"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["digest", b"digest", "path", b"path"]) -> None: ...

global___DirectoryMetadata = DirectoryMetadata

@typing_extensions.final
class Digest(google.protobuf.message.Message):
    """The CommandTask and CommandResult messages assume the existence of a service
    that can serve blobs of content, identified by a hash and size known as a
    "digest." The method by which these blobs may be retrieved is not specified
    here, but a model implementation is in the Remote Execution API's
    "ContentAddressibleStorage" interface.

    In the context of the RWAPI, a Digest will virtually always refer to the
    contents of a file or a directory. The latter is represented by the
    byte-encoded Directory message.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HASH_FIELD_NUMBER: builtins.int
    SIZE_BYTES_FIELD_NUMBER: builtins.int
    hash: builtins.str
    """A string-encoded hash (eg "1a2b3c", not the byte array [0x1a, 0x2b, 0x3c])
    using an implementation-defined hash algorithm (eg SHA-256).
    """
    size_bytes: builtins.int
    """The size of the contents. While this is not strictly required as part of an
    identifier (after all, any given hash will have exactly one canonical
    size), it's useful in almost all cases when one might want to send or
    retrieve blobs of content and is included here for this reason.
    """
    def __init__(
        self,
        *,
        hash: builtins.str = ...,
        size_bytes: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash", b"hash", "size_bytes", b"size_bytes"]) -> None: ...

global___Digest = Digest

@typing_extensions.final
class Directory(google.protobuf.message.Message):
    """The contents of a directory. Similar to the equivalent message in the Remote
    Execution API.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILES_FIELD_NUMBER: builtins.int
    DIRECTORIES_FIELD_NUMBER: builtins.int
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FileMetadata]:
        """The files in this directory"""
    @property
    def directories(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DirectoryMetadata]:
        """Any subdirectories"""
    def __init__(
        self,
        *,
        files: collections.abc.Iterable[global___FileMetadata] | None = ...,
        directories: collections.abc.Iterable[global___DirectoryMetadata] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["directories", b"directories", "files", b"files"]) -> None: ...

global___Directory = Directory



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2016 Google Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import abc
import buildgrid.common.protos.google.longrunning.operations_pb2
import google.protobuf.empty_pb2
import grpc

class OperationsStub:
    """Manages long-running operations with an API service.

    When an API method normally takes long time to complete, it can be designed
    to return [Operation][google.longrunning.Operation] to the client, and the client can use this
    interface to receive the real response asynchronously by polling the
    operation resource, or pass the operation resource to another API (such as
    Google Cloud Pub/Sub API) to receive the response.  Any API service that
    returns long-running operations should implement the `Operations` interface
    so developers can have a consistent client experience.
    """

    def __init__(self, channel: grpc.Channel) -> None: ...
    ListOperations: grpc.UnaryUnaryMultiCallable[
        buildgrid.common.protos.google.longrunning.operations_pb2.ListOperationsRequest,
        buildgrid.common.protos.google.longrunning.operations_pb2.ListOperationsResponse,
    ]
    """Lists operations that match the specified filter in the request. If the
    server doesn't support this method, it returns `UNIMPLEMENTED`.

    NOTE: the `name` binding below allows API services to override the binding
    to use different resource name schemes, such as `users/*/operations`.
    """
    GetOperation: grpc.UnaryUnaryMultiCallable[
        buildgrid.common.protos.google.longrunning.operations_pb2.GetOperationRequest,
        buildgrid.common.protos.google.longrunning.operations_pb2.Operation,
    ]
    """Gets the latest state of a long-running operation.  Clients can use this
    method to poll the operation result at intervals as recommended by the API
    service.
    """
    DeleteOperation: grpc.UnaryUnaryMultiCallable[
        buildgrid.common.protos.google.longrunning.operations_pb2.DeleteOperationRequest,
        google.protobuf.empty_pb2.Empty,
    ]
    """Deletes a long-running operation. This method indicates that the client is
    no longer interested in the operation result. It does not cancel the
    operation. If the server doesn't support this method, it returns
    `google.rpc.Code.UNIMPLEMENTED`.
    """
    CancelOperation: grpc.UnaryUnaryMultiCallable[
        buildgrid.common.protos.google.longrunning.operations_pb2.CancelOperationRequest,
        google.protobuf.empty_pb2.Empty,
    ]
    """Starts asynchronous cancellation on a long-running operation.  The server
    makes a best effort to cancel the operation, but success is not
    guaranteed.  If the server doesn't support this method, it returns
    `google.rpc.Code.UNIMPLEMENTED`.  Clients can use
    [Operations.GetOperation][google.longrunning.Operations.GetOperation] or
    other methods to check whether the cancellation succeeded or whether the
    operation completed despite cancellation. On successful cancellation,
    the operation is not deleted; instead, it becomes an operation with
    an [Operation.error][google.longrunning.Operation.error] value with a [google.rpc.Status.code][google.rpc.Status.code] of 1,
    corresponding to `Code.CANCELLED`.
    """

class OperationsServicer(metaclass=abc.ABCMeta):
    """Manages long-running operations with an API service.

    When an API method normally takes long time to complete, it can be designed
    to return [Operation][google.longrunning.Operation] to the client, and the client can use this
    interface to receive the real response asynchronously by polling the
    operation resource, or pass the operation resource to another API (such as
    Google Cloud Pub/Sub API) to receive the response.  Any API service that
    returns long-running operations should implement the `Operations` interface
    so developers can have a consistent client experience.
    """

    @abc.abstractmethod
    def ListOperations(
        self,
        request: buildgrid.common.protos.google.longrunning.operations_pb2.ListOperationsRequest,
        context: grpc.ServicerContext,
    ) -> buildgrid.common.protos.google.longrunning.operations_pb2.ListOperationsResponse:
        """Lists operations that match the specified filter in the request. If the
        server doesn't support this method, it returns `UNIMPLEMENTED`.

        NOTE: the `name` binding below allows API services to override the binding
        to use different resource name schemes, such as `users/*/operations`.
        """
    @abc.abstractmethod
    def GetOperation(
        self,
        request: buildgrid.common.protos.google.longrunning.operations_pb2.GetOperationRequest,
        context: grpc.ServicerContext,
    ) -> buildgrid.common.protos.google.longrunning.operations_pb2.Operation:
        """Gets the latest state of a long-running operation.  Clients can use this
        method to poll the operation result at intervals as recommended by the API
        service.
        """
    @abc.abstractmethod
    def DeleteOperation(
        self,
        request: buildgrid.common.protos.google.longrunning.operations_pb2.DeleteOperationRequest,
        context: grpc.ServicerContext,
    ) -> google.protobuf.empty_pb2.Empty:
        """Deletes a long-running operation. This method indicates that the client is
        no longer interested in the operation result. It does not cancel the
        operation. If the server doesn't support this method, it returns
        `google.rpc.Code.UNIMPLEMENTED`.
        """
    @abc.abstractmethod
    def CancelOperation(
        self,
        request: buildgrid.common.protos.google.longrunning.operations_pb2.CancelOperationRequest,
        context: grpc.ServicerContext,
    ) -> google.protobuf.empty_pb2.Empty:
        """Starts asynchronous cancellation on a long-running operation.  The server
        makes a best effort to cancel the operation, but success is not
        guaranteed.  If the server doesn't support this method, it returns
        `google.rpc.Code.UNIMPLEMENTED`.  Clients can use
        [Operations.GetOperation][google.longrunning.Operations.GetOperation] or
        other methods to check whether the cancellation succeeded or whether the
        operation completed despite cancellation. On successful cancellation,
        the operation is not deleted; instead, it becomes an operation with
        an [Operation.error][google.longrunning.Operation.error] value with a [google.rpc.Status.code][google.rpc.Status.code] of 1,
        corresponding to `Code.CANCELLED`.
        """

def add_OperationsServicer_to_server(servicer: OperationsServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/devtools/remoteworkers/v1test2/command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from buildgrid.common.protos.google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3google/devtools/remoteworkers/v1test2/command.proto\x12%google.devtools.remoteworkers.v1test2\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x17google/rpc/status.proto\"\xf3\x05\n\x0b\x43ommandTask\x12I\n\x06inputs\x18\x01 \x01(\x0b\x32\x39.google.devtools.remoteworkers.v1test2.CommandTask.Inputs\x12T\n\x10\x65xpected_outputs\x18\x04 \x01(\x0b\x32:.google.devtools.remoteworkers.v1test2.CommandTask.Outputs\x12M\n\x08timeouts\x18\x05 \x01(\x0b\x32;.google.devtools.remoteworkers.v1test2.CommandTask.Timeouts\x1a\xfb\x01\n\x06Inputs\x12\x11\n\targuments\x18\x01 \x03(\t\x12<\n\x05\x66iles\x18\x02 \x03(\x0b\x32-.google.devtools.remoteworkers.v1test2.Digest\x12l\n\x15\x65nvironment_variables\x18\x03 \x03(\x0b\x32M.google.devtools.remoteworkers.v1test2.CommandTask.Inputs.EnvironmentVariable\x1a\x32\n\x13\x45nvironmentVariable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x65\n\x07Outputs\x12\r\n\x05\x66iles\x18\x01 \x03(\t\x12\x13\n\x0b\x64irectories\x18\x02 \x03(\t\x12\x1a\n\x12stdout_destination\x18\x03 \x01(\t\x12\x1a\n\x12stderr_destination\x18\x04 \x01(\t\x1a\x8e\x01\n\x08Timeouts\x12,\n\texecution\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\'\n\x04idle\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08shutdown\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"c\n\x0e\x43ommandOutputs\x12\x11\n\texit_code\x18\x01 \x01(\x05\x12>\n\x07outputs\x18\x02 \x01(\x0b\x32-.google.devtools.remoteworkers.v1test2.Digest\"k\n\x0f\x43ommandOverhead\x12+\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08overhead\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x92\x02\n\rCommandResult\x12\"\n\x06status\x18\x01 \x01(\x0b\x32\x12.google.rpc.Status\x12\x11\n\texit_code\x18\x02 \x01(\x05\x12>\n\x07outputs\x18\x03 \x01(\x0b\x32-.google.devtools.remoteworkers.v1test2.Digest\x12/\n\x08\x64uration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x02\x18\x01\x12/\n\x08overhead\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\x02\x18\x01\x12(\n\nstatistics\x18\x06 \x03(\x0b\x32\x14.google.protobuf.Any\"\x84\x01\n\x0c\x46ileMetadata\x12\x0c\n\x04path\x18\x01 \x01(\t\x12=\n\x06\x64igest\x18\x02 \x01(\x0b\x32-.google.devtools.remoteworkers.v1test2.Digest\x12\x10\n\x08\x63ontents\x18\x03 \x01(\x0c\x12\x15\n\ris_executable\x18\x04 \x01(\x08\"`\n\x11\x44irectoryMetadata\x12\x0c\n\x04path\x18\x01 \x01(\t\x12=\n\x06\x64igest\x18\x02 \x01(\x0b\x32-.google.devtools.remoteworkers.v1test2.Digest\"*\n\x06\x44igest\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x12\n\nsize_bytes\x18\x02 \x01(\x03\"\x9e\x01\n\tDirectory\x12\x42\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x33.google.devtools.remoteworkers.v1test2.FileMetadata\x12M\n\x0b\x64irectories\x18\x02 \x03(\x0b\x32\x38.google.devtools.remoteworkers.v1test2.DirectoryMetadataB\xc5\x01\n)com.google.devtools.remoteworkers.v1test2B\x15RemoteWorkersCommandsP\x01ZRgoogle.golang.org/genproto/googleapis/devtools/remoteworkers/v1test2;remoteworkers\xa2\x02\x02RW\xaa\x02%Google.DevTools.RemoteWorkers.V1Test2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buildgrid.common.protos.google.devtools.remoteworkers.v1test2.command_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.google.devtools.remoteworkers.v1test2B\025RemoteWorkersCommandsP\001ZRgoogle.golang.org/genproto/googleapis/devtools/remoteworkers/v1test2;remoteworkers\242\002\002RW\252\002%Google.DevTools.RemoteWorkers.V1Test2'
  _COMMANDRESULT.fields_by_name['duration']._options = None
  _COMMANDRESULT.fields_by_name['duration']._serialized_options = b'\030\001'
  _COMMANDRESULT.fields_by_name['overhead']._options = None
  _COMMANDRESULT.fields_by_name['overhead']._serialized_options = b'\030\001'
  _globals['_COMMANDTASK']._serialized_start=179
  _globals['_COMMANDTASK']._serialized_end=934
  _globals['_COMMANDTASK_INPUTS']._serialized_start=435
  _globals['_COMMANDTASK_INPUTS']._serialized_end=686
  _globals['_COMMANDTASK_INPUTS_ENVIRONMENTVARIABLE']._serialized_start=636
  _globals['_COMMANDTASK_INPUTS_ENVIRONMENTVARIABLE']._serialized_end=686
  _globals['_COMMANDTASK_OUTPUTS']._serialized_start=688
  _globals['_COMMANDTASK_OUTPUTS']._serialized_end=789
  _globals['_COMMANDTASK_TIMEOUTS']._serialized_start=792
  _globals['_COMMANDTASK_TIMEOUTS']._serialized_end=934
  _globals['_COMMANDOUTPUTS']._serialized_start=936
  _globals['_COMMANDOUTPUTS']._serialized_end=1035
  _globals['_COMMANDOVERHEAD']._serialized_start=1037
  _globals['_COMMANDOVERHEAD']._serialized_end=1144
  _globals['_COMMANDRESULT']._serialized_start=1147
  _globals['_COMMANDRESULT']._serialized_end=1421
  _globals['_FILEMETADATA']._serialized_start=1424
  _globals['_FILEMETADATA']._serialized_end=1556
  _globals['_DIRECTORYMETADATA']._serialized_start=1558
  _globals['_DIRECTORYMETADATA']._serialized_end=1654
  _globals['_DIGEST']._serialized_start=1656
  _globals['_DIGEST']._serialized_end=1698
  _globals['_DIRECTORY']._serialized_start=1701
  _globals['_DIRECTORY']._serialized_end=1859
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/rpc/status.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17google/rpc/status.proto\x12\ngoogle.rpc\x1a\x19google/protobuf/any.proto\"N\n\x06Status\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12%\n\x07\x64\x65tails\x18\x03 \x03(\x0b\x32\x14.google.protobuf.AnyB^\n\x0e\x63om.google.rpcB\x0bStatusProtoP\x01Z7google.golang.org/genproto/googleapis/rpc/status;status\xa2\x02\x03RPCb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buildgrid.common.protos.google.rpc.status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.rpcB\013StatusProtoP\001Z7google.golang.org/genproto/googleapis/rpc/status;status\242\002\003RPC'
  _globals['_STATUS']._serialized_start=66
  _globals['_STATUS']._serialized_end=144
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2018 The Bazel Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SemVer(google.protobuf.message.Message):
    """The full version of a given tool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAJOR_FIELD_NUMBER: builtins.int
    MINOR_FIELD_NUMBER: builtins.int
    PATCH_FIELD_NUMBER: builtins.int
    PRERELEASE_FIELD_NUMBER: builtins.int
    major: builtins.int
    """The major version, e.g 10 for 10.2.3."""
    minor: builtins.int
    """The minor version, e.g. 2 for 10.2.3."""
    patch: builtins.int
    """The patch version, e.g 3 for 10.2.3."""
    prerelease: builtins.str
    """The pre-release version. Either this field or major/minor/patch fields
    must be filled. They are mutually exclusive. Pre-release versions are
    assumed to be earlier than any released versions.
    """
    def __init__(
        self,
        *,
        major: builtins.int = ...,
        minor: builtins.int = ...,
        patch: builtins.int = ...,
        prerelease: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["major", b"major", "minor", b"minor", "patch", b"patch", "prerelease", b"prerelease"]) -> None: ...

global___SemVer = SemVer



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buildgrid/v2/monitoring.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x62uildgrid/v2/monitoring.proto\x12\x0c\x62uildgrid.v2\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x93\x01\n\nBusMessage\x12\x17\n\x0fsequence_number\x18\x01 \x01(\x03\x12-\n\nlog_record\x18\x02 \x01(\x0b\x32\x17.buildgrid.v2.LogRecordH\x00\x12\x33\n\rmetric_record\x18\x03 \x01(\x0b\x32\x1a.buildgrid.v2.MetricRecordH\x00\x42\x08\n\x06record\"\xcc\x02\n\tLogRecord\x12\x36\n\x12\x63reation_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12,\n\x05level\x18\x03 \x01(\x0e\x32\x1d.buildgrid.v2.LogRecord.Level\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x37\n\x08metadata\x18\x05 \x03(\x0b\x32%.buildgrid.v2.LogRecord.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"N\n\x05Level\x12\n\n\x06NOTSET\x10\x00\x12\t\n\x05\x44\x45\x42UG\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\x0c\n\x08\x43RITICAL\x10\x05\"\x90\x03\n\x0cMetricRecord\x12\x36\n\x12\x63reation_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\x04type\x18\x03 \x01(\x0e\x32\x1f.buildgrid.v2.MetricRecord.Type\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x05\x63ount\x18\x05 \x01(\x02H\x00\x12-\n\x08\x64uration\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12\x0f\n\x05value\x18\x07 \x01(\x02H\x00\x12:\n\x08metadata\x18\x08 \x03(\x0b\x32(.buildgrid.v2.MetricRecord.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"E\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x43OUNTER\x10\x01\x12\t\n\x05TIMER\x10\x02\x12\t\n\x05GAUGE\x10\x03\x12\x10\n\x0c\x44ISTRIBUTION\x10\x04\x42\x06\n\x04\x64\x61tab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buildgrid.common.protos.buildgrid.v2.monitoring_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOGRECORD_METADATAENTRY._options = None
  _LOGRECORD_METADATAENTRY._serialized_options = b'8\001'
  _METRICRECORD_METADATAENTRY._options = None
  _METRICRECORD_METADATAENTRY._serialized_options = b'8\001'
  _globals['_BUSMESSAGE']._serialized_start=113
  _globals['_BUSMESSAGE']._serialized_end=260
  _globals['_LOGRECORD']._serialized_start=263
  _globals['_LOGRECORD']._serialized_end=595
  _globals['_LOGRECORD_METADATAENTRY']._serialized_start=468
  _globals['_LOGRECORD_METADATAENTRY']._serialized_end=515
  _globals['_LOGRECORD_LEVEL']._serialized_start=517
  _globals['_LOGRECORD_LEVEL']._serialized_end=595
  _globals['_METRICRECORD']._serialized_start=598
  _globals['_METRICRECORD']._serialized_end=998
  _globals['_METRICRECORD_METADATAENTRY']._serialized_start=468
  _globals['_METRICRECORD_METADATAENTRY']._serialized_end=515
  _globals['_METRICRECORD_TYPE']._serialized_start=921
  _globals['_METRICRECORD_TYPE']._serialized_end=990
# @@protoc_insertion_point(module_scope)



from buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2 import Digest

"""
A dummy test file as a placeholder just to ensure test tooling works
Please remove this file once the package has any testable code
"""


def test_dummy():
    # Protos can be imported and used
    digest = Digest(hash="abc", size_bytes=123)
    assert digest.hash == "abc"
    assert digest.size_bytes == 123



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2018 Codethink Limited

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import abc
import buildgrid.common.protos.buildstream.v2.buildstream_pb2
import grpc.aio as grpc
import typing

class ReferenceStorageStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetReference: grpc.UnaryUnaryMultiCallable[
        buildgrid.common.protos.buildstream.v2.buildstream_pb2.GetReferenceRequest,
        buildgrid.common.protos.buildstream.v2.buildstream_pb2.GetReferenceResponse,
    ]
    """Retrieve a CAS [Directory][build.bazel.remote.execution.v2.Directory]
    digest by name.

    Errors:
    * `NOT_FOUND`: The requested reference is not in the cache.
    """
    UpdateReference: grpc.UnaryUnaryMultiCallable[
        buildgrid.common.protos.buildstream.v2.buildstream_pb2.UpdateReferenceRequest,
        buildgrid.common.protos.buildstream.v2.buildstream_pb2.UpdateReferenceResponse,
    ]
    """Associate a name with a CAS [Directory][build.bazel.remote.execution.v2.Directory]
    digest.

    Errors:
    * `RESOURCE_EXHAUSTED`: There is insufficient storage space to add the
      entry to the cache.
    """
    Status: grpc.UnaryUnaryMultiCallable[
        buildgrid.common.protos.buildstream.v2.buildstream_pb2.StatusRequest,
        buildgrid.common.protos.buildstream.v2.buildstream_pb2.StatusResponse,
    ]

class ReferenceStorageServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    async def GetReference(
        self,
        request: buildgrid.common.protos.buildstream.v2.buildstream_pb2.GetReferenceRequest,
        context: grpc.ServicerContext[typing.Any, typing.Any],
    ) -> buildgrid.common.protos.buildstream.v2.buildstream_pb2.GetReferenceResponse:
        """Retrieve a CAS [Directory][build.bazel.remote.execution.v2.Directory]
        digest by name.

        Errors:
        * `NOT_FOUND`: The requested reference is not in the cache.
        """
    @abc.abstractmethod
    async def UpdateReference(
        self,
        request: buildgrid.common.protos.buildstream.v2.buildstream_pb2.UpdateReferenceRequest,
        context: grpc.ServicerContext[typing.Any, typing.Any],
    ) -> buildgrid.common.protos.buildstream.v2.buildstream_pb2.UpdateReferenceResponse:
        """Associate a name with a CAS [Directory][build.bazel.remote.execution.v2.Directory]
        digest.

        Errors:
        * `RESOURCE_EXHAUSTED`: There is insufficient storage space to add the
          entry to the cache.
        """
    @abc.abstractmethod
    async def Status(
        self,
        request: buildgrid.common.protos.buildstream.v2.buildstream_pb2.StatusRequest,
        context: grpc.ServicerContext[typing.Any, typing.Any],
    ) -> buildgrid.common.protos.buildstream.v2.buildstream_pb2.StatusResponse: ...

def add_ReferenceStorageServicer_to_server(servicer: ReferenceStorageServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2018 Google LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.internal.extension_dict
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FieldBehavior:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FieldBehaviorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FieldBehavior.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FIELD_BEHAVIOR_UNSPECIFIED: _FieldBehavior.ValueType  # 0
    """Conventional default for enums. Do not use this."""
    OPTIONAL: _FieldBehavior.ValueType  # 1
    """Specifically denotes a field as optional.
    While all fields in protocol buffers are optional, this may be specified
    for emphasis if appropriate.
    """
    REQUIRED: _FieldBehavior.ValueType  # 2
    """Denotes a field as required.
    This indicates that the field **must** be provided as part of the request,
    and failure to do so will cause an error (usually `INVALID_ARGUMENT`).
    """
    OUTPUT_ONLY: _FieldBehavior.ValueType  # 3
    """Denotes a field as output only.
    This indicates that the field is provided in responses, but including the
    field in a request does nothing (the server *must* ignore it and
    *must not* throw an error as a result of the field's presence).
    """
    INPUT_ONLY: _FieldBehavior.ValueType  # 4
    """Denotes a field as input only.
    This indicates that the field is provided in requests, and the
    corresponding field is not included in output.
    """
    IMMUTABLE: _FieldBehavior.ValueType  # 5
    """Denotes a field as immutable.
    This indicates that the field may be set once in a request to create a
    resource, but may not be changed thereafter.
    """
    UNORDERED_LIST: _FieldBehavior.ValueType  # 6
    """Denotes that a (repeated) field is an unordered list.
    This indicates that the service may provide the elements of the list
    in any arbitrary  order, rather than the order the user originally
    provided. Additionally, the list's order may or may not be stable.
    """
    NON_EMPTY_DEFAULT: _FieldBehavior.ValueType  # 7
    """Denotes that this field returns a non-empty default value if not set.
    This indicates that if the user provides the empty value in a request,
    a non-empty value will be returned. The user will not be aware of what
    non-empty value to expect.
    """

class FieldBehavior(_FieldBehavior, metaclass=_FieldBehaviorEnumTypeWrapper):
    """An indicator of the behavior of a given field (for example, that a field
    is required in requests, or given as output but ignored as input).
    This **does not** change the behavior in protocol buffers itself; it only
    denotes the behavior and may affect how API tooling handles the field.

    Note: This enum **may** receive new values in the future.
    """

FIELD_BEHAVIOR_UNSPECIFIED: FieldBehavior.ValueType  # 0
"""Conventional default for enums. Do not use this."""
OPTIONAL: FieldBehavior.ValueType  # 1
"""Specifically denotes a field as optional.
While all fields in protocol buffers are optional, this may be specified
for emphasis if appropriate.
"""
REQUIRED: FieldBehavior.ValueType  # 2
"""Denotes a field as required.
This indicates that the field **must** be provided as part of the request,
and failure to do so will cause an error (usually `INVALID_ARGUMENT`).
"""
OUTPUT_ONLY: FieldBehavior.ValueType  # 3
"""Denotes a field as output only.
This indicates that the field is provided in responses, but including the
field in a request does nothing (the server *must* ignore it and
*must not* throw an error as a result of the field's presence).
"""
INPUT_ONLY: FieldBehavior.ValueType  # 4
"""Denotes a field as input only.
This indicates that the field is provided in requests, and the
corresponding field is not included in output.
"""
IMMUTABLE: FieldBehavior.ValueType  # 5
"""Denotes a field as immutable.
This indicates that the field may be set once in a request to create a
resource, but may not be changed thereafter.
"""
UNORDERED_LIST: FieldBehavior.ValueType  # 6
"""Denotes that a (repeated) field is an unordered list.
This indicates that the service may provide the elements of the list
in any arbitrary  order, rather than the order the user originally
provided. Additionally, the list's order may or may not be stable.
"""
NON_EMPTY_DEFAULT: FieldBehavior.ValueType  # 7
"""Denotes that this field returns a non-empty default value if not set.
This indicates that if the user provides the empty value in a request,
a non-empty value will be returned. The user will not be aware of what
non-empty value to expect.
"""
global___FieldBehavior = FieldBehavior

FIELD_BEHAVIOR_FIELD_NUMBER: builtins.int
field_behavior: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___FieldBehavior.ValueType]]
"""A designation of a specific field behavior (required, output only, etc.)
in protobuf messages.

Examples:

  string name = 1 [(google.api.field_behavior) = REQUIRED];
  State state = 1 [(google.api.field_behavior) = OUTPUT_ONLY];
  google.protobuf.Duration ttl = 1
    [(google.api.field_behavior) = INPUT_ONLY];
  google.protobuf.Timestamp expire_time = 1
    [(google.api.field_behavior) = OUTPUT_ONLY,
     (google.api.field_behavior) = IMMUTABLE];
"""



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/devtools/remoteworkers/v1test2/tasks.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buildgrid.common.protos.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from buildgrid.common.protos.google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1google/devtools/remoteworkers/v1test2/tasks.proto\x12%google.devtools.remoteworkers.v1test2\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\x1a google/protobuf/field_mask.proto\x1a\x17google/rpc/status.proto\"\xb1\x01\n\x04Task\x12\x0c\n\x04name\x18\x01 \x01(\t\x12)\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x43\n\x04logs\x18\x03 \x03(\x0b\x32\x35.google.devtools.remoteworkers.v1test2.Task.LogsEntry\x1a+\n\tLogsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x01\n\nTaskResult\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63omplete\x18\x02 \x01(\x08\x12\"\n\x06status\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\x12$\n\x06output\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\"\n\x04meta\x18\x05 \x01(\x0b\x32\x14.google.protobuf.Any\"\x1e\n\x0eGetTaskRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xab\x01\n\x17UpdateTaskResultRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x41\n\x06result\x18\x02 \x01(\x0b\x32\x31.google.devtools.remoteworkers.v1test2.TaskResult\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0e\n\x06source\x18\x04 \x01(\t\"1\n\x11\x41\x64\x64TaskLogRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06log_id\x18\x02 \x01(\t\"$\n\x12\x41\x64\x64TaskLogResponse\x12\x0e\n\x06handle\x18\x01 \x01(\t2\x88\x04\n\x05Tasks\x12\x91\x01\n\x07GetTask\x12\x35.google.devtools.remoteworkers.v1test2.GetTaskRequest\x1a+.google.devtools.remoteworkers.v1test2.Task\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1test2/{name=**/tasks/*}\x12\xb8\x01\n\x10UpdateTaskResult\x12>.google.devtools.remoteworkers.v1test2.UpdateTaskResultRequest\x1a\x31.google.devtools.remoteworkers.v1test2.TaskResult\"1\x82\xd3\xe4\x93\x02+2!/v1test2/{name=**/tasks/*/result}:\x06result\x12\xaf\x01\n\nAddTaskLog\x12\x38.google.devtools.remoteworkers.v1test2.AddTaskLogRequest\x1a\x39.google.devtools.remoteworkers.v1test2.AddTaskLogResponse\",\x82\xd3\xe4\x93\x02&\"!/v1test2/{name=**/tasks/*}:addLog:\x01*B\xc2\x01\n)com.google.devtools.remoteworkers.v1test2B\x12RemoteWorkersTasksP\x01ZRgoogle.golang.org/genproto/googleapis/devtools/remoteworkers/v1test2;remoteworkers\xa2\x02\x02RW\xaa\x02%Google.DevTools.RemoteWorkers.V1Test2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buildgrid.common.protos.google.devtools.remoteworkers.v1test2.tasks_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.google.devtools.remoteworkers.v1test2B\022RemoteWorkersTasksP\001ZRgoogle.golang.org/genproto/googleapis/devtools/remoteworkers/v1test2;remoteworkers\242\002\002RW\252\002%Google.DevTools.RemoteWorkers.V1Test2'
  _TASK_LOGSENTRY._options = None
  _TASK_LOGSENTRY._serialized_options = b'8\001'
  _TASKS.methods_by_name['GetTask']._options = None
  _TASKS.methods_by_name['GetTask']._serialized_options = b'\202\323\344\223\002\034\022\032/v1test2/{name=**/tasks/*}'
  _TASKS.methods_by_name['UpdateTaskResult']._options = None
  _TASKS.methods_by_name['UpdateTaskResult']._serialized_options = b'\202\323\344\223\002+2!/v1test2/{name=**/tasks/*/result}:\006result'
  _TASKS.methods_by_name['AddTaskLog']._options = None
  _TASKS.methods_by_name['AddTaskLog']._serialized_options = b'\202\323\344\223\002&\"!/v1test2/{name=**/tasks/*}:addLog:\001*'
  _globals['_TASK']._serialized_start=209
  _globals['_TASK']._serialized_end=386
  _globals['_TASK_LOGSENTRY']._serialized_start=343
  _globals['_TASK_LOGSENTRY']._serialized_end=386
  _globals['_TASKRESULT']._serialized_start=389
  _globals['_TASKRESULT']._serialized_end=543
  _globals['_GETTASKREQUEST']._serialized_start=545
  _globals['_GETTASKREQUEST']._serialized_end=575
  _globals['_UPDATETASKRESULTREQUEST']._serialized_start=578
  _globals['_UPDATETASKRESULTREQUEST']._serialized_end=749
  _globals['_ADDTASKLOGREQUEST']._serialized_start=751
  _globals['_ADDTASKLOGREQUEST']._serialized_end=800
  _globals['_ADDTASKLOGRESPONSE']._serialized_start=802
  _globals['_ADDTASKLOGRESPONSE']._serialized_end=838
  _globals['_TASKS']._serialized_start=841
  _globals['_TASKS']._serialized_end=1361
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2020 Google LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import abc
import collections.abc
import buildgrid.common.protos.google.devtools.build.v1.publish_build_event_pb2
import google.protobuf.empty_pb2
import grpc

class PublishBuildEventStub:
    """A service for publishing BuildEvents. BuildEvents are generated by Build
    Systems to record actions taken during a Build. Events occur in streams,
    are identified by a StreamId, and ordered by sequence number in a stream.

    A Build may contain several streams of BuildEvents, depending on the systems
    that are involved in the Build. Some BuildEvents are used to declare the
    beginning and end of major portions of a Build; these are called
    LifecycleEvents, and are used (for example) to indicate the beginning or end
    of a Build, and the beginning or end of an Invocation attempt (there can be
    more than 1 Invocation in a Build if, for example, a failure occurs somewhere
    and it needs to be retried).

    Other, build-tool events represent actions taken by the Build tool, such as
    target objects produced via compilation, tests run, et cetera. There could be
    more than one build tool stream for an invocation attempt of a build.
    """

    def __init__(self, channel: grpc.Channel) -> None: ...
    PublishLifecycleEvent: grpc.UnaryUnaryMultiCallable[
        buildgrid.common.protos.google.devtools.build.v1.publish_build_event_pb2.PublishLifecycleEventRequest,
        google.protobuf.empty_pb2.Empty,
    ]
    """Publish a build event stating the new state of a build (typically from the
    build queue). The BuildEnqueued event must be publishd before all other
    events for the same build ID.

    The backend will persist the event and deliver it to registered frontend
    jobs immediately without batching.

    The commit status of the request is reported by the RPC's util_status()
    function. The error code is the canoncial error code defined in
    //util/task/codes.proto.
    """
    PublishBuildToolEventStream: grpc.StreamStreamMultiCallable[
        buildgrid.common.protos.google.devtools.build.v1.publish_build_event_pb2.PublishBuildToolEventStreamRequest,
        buildgrid.common.protos.google.devtools.build.v1.publish_build_event_pb2.PublishBuildToolEventStreamResponse,
    ]
    """Publish build tool events belonging to the same stream to a backend job
    using bidirectional streaming.
    """

class PublishBuildEventServicer(metaclass=abc.ABCMeta):
    """A service for publishing BuildEvents. BuildEvents are generated by Build
    Systems to record actions taken during a Build. Events occur in streams,
    are identified by a StreamId, and ordered by sequence number in a stream.

    A Build may contain several streams of BuildEvents, depending on the systems
    that are involved in the Build. Some BuildEvents are used to declare the
    beginning and end of major portions of a Build; these are called
    LifecycleEvents, and are used (for example) to indicate the beginning or end
    of a Build, and the beginning or end of an Invocation attempt (there can be
    more than 1 Invocation in a Build if, for example, a failure occurs somewhere
    and it needs to be retried).

    Other, build-tool events represent actions taken by the Build tool, such as
    target objects produced via compilation, tests run, et cetera. There could be
    more than one build tool stream for an invocation attempt of a build.
    """

    @abc.abstractmethod
    def PublishLifecycleEvent(
        self,
        request: buildgrid.common.protos.google.devtools.build.v1.publish_build_event_pb2.PublishLifecycleEventRequest,
        context: grpc.ServicerContext,
    ) -> google.protobuf.empty_pb2.Empty:
        """Publish a build event stating the new state of a build (typically from the
        build queue). The BuildEnqueued event must be publishd before all other
        events for the same build ID.

        The backend will persist the event and deliver it to registered frontend
        jobs immediately without batching.

        The commit status of the request is reported by the RPC's util_status()
        function. The error code is the canoncial error code defined in
        //util/task/codes.proto.
        """
    @abc.abstractmethod
    def PublishBuildToolEventStream(
        self,
        request_iterator: collections.abc.Iterator[buildgrid.common.protos.google.devtools.build.v1.publish_build_event_pb2.PublishBuildToolEventStreamRequest],
        context: grpc.ServicerContext,
    ) -> collections.abc.Iterator[buildgrid.common.protos.google.devtools.build.v1.publish_build_event_pb2.PublishBuildToolEventStreamResponse]:
        """Publish build tool events belonging to the same stream to a backend job
        using bidirectional streaming.
        """

def add_PublishBuildEventServicer_to_server(servicer: PublishBuildEventServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buildgrid/v2/query_build_events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buildgrid.common.protos.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from buildgrid.common.protos.google.devtools.build.v1 import build_events_pb2 as google_dot_devtools_dot_build_dot_v1_dot_build__events__pb2
from buildgrid.common.protos.google.devtools.build.v1 import publish_build_event_pb2 as google_dot_devtools_dot_build_dot_v1_dot_publish__build__event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%buildgrid/v2/query_build_events.proto\x12\x0c\x62uildgrid.v2\x1a\x1cgoogle/api/annotations.proto\x1a+google/devtools/build/v1/build_events.proto\x1a\x32google/devtools/build/v1/publish_build_event.proto\"4\n\x18QueryEventStreamsRequest\x12\x18\n\x10\x62uild_id_pattern\x18\x01 \x01(\t\"\xef\x01\n\x19QueryEventStreamsResponse\x12I\n\x07streams\x18\x01 \x03(\x0b\x32\x38.buildgrid.v2.QueryEventStreamsResponse.BuildEventStream\x1a\x86\x01\n\x10\x42uildEventStream\x12\x35\n\tstream_id\x18\x01 \x01(\x0b\x32\".google.devtools.build.v1.StreamId\x12;\n\x06\x65vents\x18\x02 \x03(\x0b\x32+.google.devtools.build.v1.OrderedBuildEvent2\x9b\x01\n\x10QueryBuildEvents\x12\x86\x01\n\x11QueryEventStreams\x12&.buildgrid.v2.QueryEventStreamsRequest\x1a\'.buildgrid.v2.QueryEventStreamsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v2/{name=event_streams}b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buildgrid.common.protos.buildgrid.v2.query_build_events_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _QUERYBUILDEVENTS.methods_by_name['QueryEventStreams']._options = None
  _QUERYBUILDEVENTS.methods_by_name['QueryEventStreams']._serialized_options = b'\202\323\344\223\002\032\022\030/v2/{name=event_streams}'
  _globals['_QUERYEVENTSTREAMSREQUEST']._serialized_start=182
  _globals['_QUERYEVENTSTREAMSREQUEST']._serialized_end=234
  _globals['_QUERYEVENTSTREAMSRESPONSE']._serialized_start=237
  _globals['_QUERYEVENTSTREAMSRESPONSE']._serialized_end=476
  _globals['_QUERYEVENTSTREAMSRESPONSE_BUILDEVENTSTREAM']._serialized_start=342
  _globals['_QUERYEVENTSTREAMSRESPONSE_BUILDEVENTSTREAM']._serialized_end=476
  _globals['_QUERYBUILDEVENTS']._serialized_start=479
  _globals['_QUERYBUILDEVENTS']._serialized_end=634
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2017 Google Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Status(google.protobuf.message.Message):
    """The `Status` type defines a logical error model that is suitable for different
    programming environments, including REST APIs and RPC APIs. It is used by
    [gRPC](https://github.com/grpc). The error model is designed to be:

    - Simple to use and understand for most users
    - Flexible enough to meet unexpected needs

    # Overview

    The `Status` message contains three pieces of data: error code, error message,
    and error details. The error code should be an enum value of
    [google.rpc.Code][google.rpc.Code], but it may accept additional error codes if needed.  The
    error message should be a developer-facing English message that helps
    developers *understand* and *resolve* the error. If a localized user-facing
    error message is needed, put the localized message in the error details or
    localize it in the client. The optional error details may contain arbitrary
    information about the error. There is a predefined set of error detail types
    in the package `google.rpc` that can be used for common error conditions.

    # Language mapping

    The `Status` message is the logical representation of the error model, but it
    is not necessarily the actual wire format. When the `Status` message is
    exposed in different client libraries and different wire protocols, it can be
    mapped differently. For example, it will likely be mapped to some exceptions
    in Java, but more likely mapped to some error codes in C.

    # Other uses

    The error model and the `Status` message can be used in a variety of
    environments, either with or without APIs, to provide a
    consistent developer experience across different environments.

    Example uses of this error model include:

    - Partial errors. If a service needs to return partial errors to the client,
        it may embed the `Status` in the normal response to indicate the partial
        errors.

    - Workflow errors. A typical workflow has multiple steps. Each step may
        have a `Status` message for error reporting.

    - Batch operations. If a client uses batch request and batch response, the
        `Status` message should be used directly inside batch response, one for
        each error sub-response.

    - Asynchronous operations. If an API call embeds asynchronous operation
        results in its response, the status of those operations should be
        represented directly using the `Status` message.

    - Logging. If some API errors are stored in logs, the message `Status` could
        be used directly after any stripping needed for security/privacy reasons.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    code: builtins.int
    """The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code]."""
    message: builtins.str
    """A developer-facing error message, which should be in English. Any
    user-facing error message should be localized and sent in the
    [google.rpc.Status.details][google.rpc.Status.details] field, or localized by the client.
    """
    @property
    def details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """A list of messages that carry the error details.  There is a common set of
        message types for APIs to use.
        """
    def __init__(
        self,
        *,
        code: builtins.int = ...,
        message: builtins.str = ...,
        details: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "details", b"details", "message", b"message"]) -> None: ...

global___Status = Status



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/devtools/remoteworkers/v1test2/bots.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buildgrid.common.protos.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from buildgrid.common.protos.google.devtools.remoteworkers.v1test2 import worker_pb2 as google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_worker__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from buildgrid.common.protos.google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0google/devtools/remoteworkers/v1test2/bots.proto\x12%google.devtools.remoteworkers.v1test2\x1a\x1cgoogle/api/annotations.proto\x1a\x32google/devtools/remoteworkers/v1test2/worker.proto\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\"\xab\x02\n\nBotSession\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x62ot_id\x18\x02 \x01(\t\x12@\n\x06status\x18\x03 \x01(\x0e\x32\x30.google.devtools.remoteworkers.v1test2.BotStatus\x12=\n\x06worker\x18\x04 \x01(\x0b\x32-.google.devtools.remoteworkers.v1test2.Worker\x12<\n\x06leases\x18\x05 \x03(\x0b\x32,.google.devtools.remoteworkers.v1test2.Lease\x12/\n\x0b\x65xpire_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07version\x18\x07 \x01(\t\"\x89\x03\n\x05Lease\x12\n\n\x02id\x18\x07 \x01(\t\x12%\n\x07payload\x18\x08 \x01(\x0b\x32\x14.google.protobuf.Any\x12$\n\x06result\x18\t \x01(\x0b\x32\x14.google.protobuf.Any\x12@\n\x05state\x18\x02 \x01(\x0e\x32\x31.google.devtools.remoteworkers.v1test2.LeaseState\x12\"\n\x06status\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\x12\x43\n\x0crequirements\x18\x04 \x01(\x0b\x32-.google.devtools.remoteworkers.v1test2.Worker\x12/\n\x0b\x65xpire_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\nassignment\x18\x01 \x01(\tB\x02\x18\x01\x12\x33\n\x11inline_assignment\x18\x06 \x01(\x0b\x32\x14.google.protobuf.AnyB\x02\x18\x01\"\xc5\x01\n\tAdminTemp\x12I\n\x07\x63ommand\x18\x01 \x01(\x0e\x32\x38.google.devtools.remoteworkers.v1test2.AdminTemp.Command\x12\x0b\n\x03\x61rg\x18\x02 \x01(\t\"`\n\x07\x43ommand\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0e\n\nBOT_UPDATE\x10\x01\x12\x0f\n\x0b\x42OT_RESTART\x10\x02\x12\x11\n\rBOT_TERMINATE\x10\x03\x12\x10\n\x0cHOST_RESTART\x10\x04\"q\n\x17\x43reateBotSessionRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x46\n\x0b\x62ot_session\x18\x02 \x01(\x0b\x32\x31.google.devtools.remoteworkers.v1test2.BotSession\"\xa0\x01\n\x17UpdateBotSessionRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x46\n\x0b\x62ot_session\x18\x02 \x01(\x0b\x32\x31.google.devtools.remoteworkers.v1test2.BotSession\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\xb5\x01\n\x17PostBotEventTempRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12Q\n\x04type\x18\x02 \x01(\x0e\x32\x43.google.devtools.remoteworkers.v1test2.PostBotEventTempRequest.Type\x12\x0b\n\x03msg\x18\x03 \x01(\t\",\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\t\n\x05\x45RROR\x10\x02*g\n\tBotStatus\x12\x1a\n\x16\x42OT_STATUS_UNSPECIFIED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\r\n\tUNHEALTHY\x10\x02\x12\x12\n\x0eHOST_REBOOTING\x10\x03\x12\x13\n\x0f\x42OT_TERMINATING\x10\x04*`\n\nLeaseState\x12\x1b\n\x17LEASE_STATE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\r\n\tCOMPLETED\x10\x04\x12\r\n\tCANCELLED\x10\x05\x32\xa8\x04\n\x04\x42ots\x12\xbc\x01\n\x10\x43reateBotSession\x12>.google.devtools.remoteworkers.v1test2.CreateBotSessionRequest\x1a\x31.google.devtools.remoteworkers.v1test2.BotSession\"5\x82\xd3\xe4\x93\x02/\" /v1test2/{parent=**}/botSessions:\x0b\x62ot_session\x12\xbc\x01\n\x10UpdateBotSession\x12>.google.devtools.remoteworkers.v1test2.UpdateBotSessionRequest\x1a\x31.google.devtools.remoteworkers.v1test2.BotSession\"5\x82\xd3\xe4\x93\x02/2 /v1test2/{name=**/botSessions/*}:\x0b\x62ot_session\x12\xa1\x01\n\x10PostBotEventTemp\x12>.google.devtools.remoteworkers.v1test2.PostBotEventTempRequest\x1a\x16.google.protobuf.Empty\"5\x82\xd3\xe4\x93\x02/\"*/v1test2/{name=**/botSessions/*}:postEvent:\x01*B\xc1\x01\n)com.google.devtools.remoteworkers.v1test2B\x11RemoteWorkersBotsP\x01ZRgoogle.golang.org/genproto/googleapis/devtools/remoteworkers/v1test2;remoteworkers\xa2\x02\x02RW\xaa\x02%Google.DevTools.RemoteWorkers.V1Test2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buildgrid.common.protos.google.devtools.remoteworkers.v1test2.bots_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.google.devtools.remoteworkers.v1test2B\021RemoteWorkersBotsP\001ZRgoogle.golang.org/genproto/googleapis/devtools/remoteworkers/v1test2;remoteworkers\242\002\002RW\252\002%Google.DevTools.RemoteWorkers.V1Test2'
  _LEASE.fields_by_name['assignment']._options = None
  _LEASE.fields_by_name['assignment']._serialized_options = b'\030\001'
  _LEASE.fields_by_name['inline_assignment']._options = None
  _LEASE.fields_by_name['inline_assignment']._serialized_options = b'\030\001'
  _BOTS.methods_by_name['CreateBotSession']._options = None
  _BOTS.methods_by_name['CreateBotSession']._serialized_options = b'\202\323\344\223\002/\" /v1test2/{parent=**}/botSessions:\013bot_session'
  _BOTS.methods_by_name['UpdateBotSession']._options = None
  _BOTS.methods_by_name['UpdateBotSession']._serialized_options = b'\202\323\344\223\002/2 /v1test2/{name=**/botSessions/*}:\013bot_session'
  _BOTS.methods_by_name['PostBotEventTemp']._options = None
  _BOTS.methods_by_name['PostBotEventTemp']._serialized_options = b'\202\323\344\223\002/\"*/v1test2/{name=**/botSessions/*}:postEvent:\001*'
  _globals['_BOTSTATUS']._serialized_start=1681
  _globals['_BOTSTATUS']._serialized_end=1784
  _globals['_LEASESTATE']._serialized_start=1786
  _globals['_LEASESTATE']._serialized_end=1882
  _globals['_BOTSESSION']._serialized_start=322
  _globals['_BOTSESSION']._serialized_end=621
  _globals['_LEASE']._serialized_start=624
  _globals['_LEASE']._serialized_end=1017
  _globals['_ADMINTEMP']._serialized_start=1020
  _globals['_ADMINTEMP']._serialized_end=1217
  _globals['_ADMINTEMP_COMMAND']._serialized_start=1121
  _globals['_ADMINTEMP_COMMAND']._serialized_end=1217
  _globals['_CREATEBOTSESSIONREQUEST']._serialized_start=1219
  _globals['_CREATEBOTSESSIONREQUEST']._serialized_end=1332
  _globals['_UPDATEBOTSESSIONREQUEST']._serialized_start=1335
  _globals['_UPDATEBOTSESSIONREQUEST']._serialized_end=1495
  _globals['_POSTBOTEVENTTEMPREQUEST']._serialized_start=1498
  _globals['_POSTBOTEVENTTEMPREQUEST']._serialized_end=1679
  _globals['_POSTBOTEVENTTEMPREQUEST_TYPE']._serialized_start=1635
  _globals['_POSTBOTEVENTTEMPREQUEST_TYPE']._serialized_end=1679
  _globals['_BOTS']._serialized_start=1885
  _globals['_BOTS']._serialized_end=2437
# @@protoc_insertion_point(module_scope)
